import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';

//redering svg tag from html
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

//Creating Line graph
const render = data => { 
  //Declaring constants we are using
  const title = 'MCU Phase Line Chart';
  
  const xValue = d => d.USreleaseDate; //display dates on x axis
  const xAxisLabel = 'USreleaseDate';

  const yValue = d => d.Phase; //display salees value on y axis
  const yAxisLabel = 'Phase';
  
  const margin = { top: 60, right: 30, bottom: 88, left: 100 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  //container
  
  
  //center g in svg
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  // Create X scale with year values
  const xScale = scaleTime()
  //complete set of values
    .domain(extent(data, xValue)) 
  //returns the minimum and maximum value in an array from the given array using natural order.
    .range([0, innerWidth]) //output bounds
    .nice(); //round values out
  //creating xAxis  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  // Create Y scale with sales values
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();
  
  //creating yAxis  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  //Appending Y axis label to svg
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  	yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -60)
      .attr('x', -innerHeight / 3)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  //Appending X axis label to svg
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  //Creating line graphs between x and y axis
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d))); //coordinates in pixels
  
  //Appending line graph to svg
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
  //Appending title of graph to svg
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};
//Loading data from URI
csv('https://gist.githubusercontent.com/happymail6/cd134b642115a7bff663865b0b0bbeb2/raw/b973000ac5b23b8f6ac95729a789a7d30c68aa04/MCU.csv')
  .then(data => {
  	//console.log(data)
    data.forEach(d => {
    	d.Phase = +d.Phase; 
      d.USreleaseDate = new Date(d.USreleaseDate)
    });
    render(data);
  });